"""
Python module generated from Java source file org.bukkit.entity.Boss

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.boss import BossBar
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Boss(Entity):
    """
    Represents the Boss Entity.
    """

    def getBossBar(self) -> "BossBar":
        """
        Returns the BossBar of the Boss

        Returns
        - the BossBar of the entity
        """
        ...



"""
Python module generated from Java source file org.bukkit.registry.RegistryAware

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.registry import *
from typing import Any, Callable, Iterable, Tuple


class RegistryAware:
    """
    Indicates that instances of a class may be registered to the server and have a key associated with them.

    See
    - Registry
    """

    def getKeyOrThrow(self) -> "NamespacedKey":
        """
        Gets the key of this instance if it is registered otherwise throws an error.
        
        This is a convenience method and plugins should always check .isRegistered() before using this method.

        Returns
        - the key with which this instance is registered.

        Raises
        - IllegalStateException: if this instance is not registered.

        See
        - Registry
        """
        ...


    def getKeyOrNull(self) -> "NamespacedKey":
        """
        Gets the key of this instance if it is registered otherwise returns `null`.

        Returns
        - the key with which this instance is registered or `null` if not registered.

        See
        - Registry
        """
        ...


    def isRegistered(self) -> bool:
        """
        Returns whether this instance is register in a registry and therefore has a key or not.

        Returns
        - True, if this instance is registered. Otherwise, False.

        See
        - Registry
        """
        ...



"""
Python module generated from Java source file java.util.function.ToIntFunction

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class ToIntFunction:
    """
    Represents a function that produces an int-valued result.  This is the
    `int`-producing primitive specialization for Function.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .applyAsInt(Object).
    
    Type `<T>`: the type of the input to the function

    See
    - Function

    Since
    - 1.8
    """

    def applyAsInt(self, value: "T") -> int:
        """
        Applies this function to the given argument.

        Arguments
        - value: the function argument

        Returns
        - the function result
        """
        ...



"""
Python module generated from Java source file org.joml.MemUtil

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Field
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class MemUtil:
    """
    Helper class to do efficient memory operations on all JOML objects, NIO buffers and primitive arrays.
    This class is used internally throughout JOML, is undocumented and is subject to change.
    Use with extreme caution!

    Author(s)
    - Kai Burjack
    """

    INSTANCE = createInstance()


    def put(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put4x4(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put3x3(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put3x3(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put3x3(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put3x3(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x3(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put4x3(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put3x4(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putf(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putf(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def putTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putfTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putf(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def putf(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector4d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, src: "Vector4d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector4f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, src: "Vector4f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector4i", offset: int, dest: "IntBuffer") -> None:
        ...


    def put(self, src: "Vector4i", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector4L", offset: int, dest: "LongBuffer") -> None:
        ...


    def put(self, src: "Vector4L", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector3f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, src: "Vector3f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector3d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, src: "Vector3d", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def putf(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector3i", offset: int, dest: "IntBuffer") -> None:
        ...


    def put(self, src: "Vector3i", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector3L", offset: int, dest: "LongBuffer") -> None:
        ...


    def put(self, src: "Vector3L", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector2f", offset: int, dest: "FloatBuffer") -> None:
        ...


    def put(self, src: "Vector2f", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector2d", offset: int, dest: "DoubleBuffer") -> None:
        ...


    def put(self, src: "Vector2d", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector2i", offset: int, dest: "IntBuffer") -> None:
        ...


    def put(self, src: "Vector2i", offset: int, dest: "ByteBuffer") -> None:
        ...


    def put(self, src: "Vector2L", offset: int, dest: "LongBuffer") -> None:
        ...


    def put(self, src: "Vector2L", offset: int, dest: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix4f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix4f", offset: int, src: "ByteBuffer") -> None:
        ...


    def getTransposed(self, m: "Matrix4f", offset: int, src: "FloatBuffer") -> None:
        ...


    def getTransposed(self, m: "Matrix4f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix4x3f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix4x3f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix4d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix4x3d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
        ...


    def getf(self, m: "Matrix4d", offset: int, src: "FloatBuffer") -> None:
        ...


    def getf(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
        ...


    def getf(self, m: "Matrix4x3d", offset: int, src: "FloatBuffer") -> None:
        ...


    def getf(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix3f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix3f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix3d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix3x2f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix3x2f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix3x2d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, m: "Matrix3x2d", offset: int, src: "ByteBuffer") -> None:
        ...


    def getf(self, m: "Matrix3d", offset: int, src: "FloatBuffer") -> None:
        ...


    def getf(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix2f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix2f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, m: "Matrix2d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
        ...


    def getf(self, m: "Matrix2d", offset: int, src: "FloatBuffer") -> None:
        ...


    def getf(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector4d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, dst: "Vector4d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector4f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, dst: "Vector4f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector4i", offset: int, src: "IntBuffer") -> None:
        ...


    def get(self, dst: "Vector4i", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector4L", offset: int, src: "LongBuffer") -> None:
        ...


    def get(self, dst: "Vector4L", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector3f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, dst: "Vector3f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector3d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, dst: "Vector3d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector3i", offset: int, src: "IntBuffer") -> None:
        ...


    def get(self, dst: "Vector3i", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector3L", offset: int, src: "LongBuffer") -> None:
        ...


    def get(self, dst: "Vector3L", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector2f", offset: int, src: "FloatBuffer") -> None:
        ...


    def get(self, dst: "Vector2f", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector2d", offset: int, src: "DoubleBuffer") -> None:
        ...


    def get(self, dst: "Vector2d", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector2i", offset: int, src: "IntBuffer") -> None:
        ...


    def get(self, dst: "Vector2i", offset: int, src: "ByteBuffer") -> None:
        ...


    def get(self, dst: "Vector2L", offset: int, src: "LongBuffer") -> None:
        ...


    def get(self, dst: "Vector2L", offset: int, src: "ByteBuffer") -> None:
        ...


    def putMatrix3f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
        ...


    def putMatrix3f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
        ...


    def putMatrix4f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
        ...


    def putMatrix4f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
        ...


    def putMatrix4x3f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
        ...


    def putMatrix4x3f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
        ...


    def get(self, m: "Matrix4f", column: int, row: int) -> float:
        ...


    def set(self, m: "Matrix4f", column: int, row: int, v: float) -> "Matrix4f":
        ...


    def get(self, m: "Matrix4d", column: int, row: int) -> float:
        ...


    def set(self, m: "Matrix4d", column: int, row: int, v: float) -> "Matrix4d":
        ...


    def get(self, m: "Matrix3f", column: int, row: int) -> float:
        ...


    def set(self, m: "Matrix3f", column: int, row: int, v: float) -> "Matrix3f":
        ...


    def get(self, m: "Matrix3d", column: int, row: int) -> float:
        ...


    def set(self, m: "Matrix3d", column: int, row: int, v: float) -> "Matrix3d":
        ...


    def getColumn(self, m: "Matrix4f", column: int, dest: "Vector4f") -> "Vector4f":
        ...


    def setColumn(self, v: "Vector4f", column: int, dest: "Matrix4f") -> "Matrix4f":
        ...


    def setColumn(self, v: "Vector4fc", column: int, dest: "Matrix4f") -> "Matrix4f":
        ...


    def copy(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
        ...


    def copy(self, src: "Matrix4x3fc", dest: "Matrix4x3f") -> None:
        ...


    def copy(self, src: "Matrix4fc", dest: "Matrix4x3f") -> None:
        ...


    def copy(self, src: "Matrix4x3fc", dest: "Matrix4f") -> None:
        ...


    def copy(self, src: "Matrix3fc", dest: "Matrix3f") -> None:
        ...


    def copy(self, src: "Matrix3fc", dest: "Matrix4f") -> None:
        ...


    def copy(self, src: "Matrix4fc", dest: "Matrix3f") -> None:
        ...


    def copy(self, src: "Matrix3fc", dest: "Matrix4x3f") -> None:
        ...


    def copy(self, src: "Matrix3x2fc", dest: "Matrix3x2f") -> None:
        ...


    def copy(self, src: "Matrix3x2dc", dest: "Matrix3x2d") -> None:
        ...


    def copy(self, src: "Matrix2fc", dest: "Matrix2f") -> None:
        ...


    def copy(self, src: "Matrix2dc", dest: "Matrix2d") -> None:
        ...


    def copy(self, src: "Matrix2fc", dest: "Matrix3f") -> None:
        ...


    def copy(self, src: "Matrix3fc", dest: "Matrix2f") -> None:
        ...


    def copy(self, src: "Matrix2fc", dest: "Matrix3x2f") -> None:
        ...


    def copy(self, src: "Matrix3x2fc", dest: "Matrix2f") -> None:
        ...


    def copy(self, src: "Matrix2dc", dest: "Matrix3d") -> None:
        ...


    def copy(self, src: "Matrix3dc", dest: "Matrix2d") -> None:
        ...


    def copy(self, src: "Matrix2dc", dest: "Matrix3x2d") -> None:
        ...


    def copy(self, src: "Matrix3x2dc", dest: "Matrix2d") -> None:
        ...


    def copy3x3(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
        ...


    def copy3x3(self, src: "Matrix4x3fc", dest: "Matrix4x3f") -> None:
        ...


    def copy3x3(self, src: "Matrix3fc", dest: "Matrix4x3f") -> None:
        ...


    def copy3x3(self, src: "Matrix3fc", dest: "Matrix4f") -> None:
        ...


    def copy4x3(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
        ...


    def copy4x3(self, src: "Matrix4x3fc", dest: "Matrix4f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix4f") -> None:
        ...


    def copyTransposed(self, arr: list[float], off: int, dest: "Matrix4f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix3f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix4x3f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix3x2f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix3x2d") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix3x2d") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix2f") -> None:
        ...


    def copy(self, arr: list[float], off: int, dest: "Matrix2d") -> None:
        ...


    def copy(self, src: "Matrix4fc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix3fc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix4x3fc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix2fc", dest: list[float], off: int) -> None:
        ...


    def copy(self, src: "Matrix2dc", dest: list[float], off: int) -> None:
        ...


    def copy4x4(self, src: "Matrix4x3fc", dest: list[float], off: int) -> None:
        ...


    def copy4x4(self, src: "Matrix4x3dc", dest: list[float], off: int) -> None:
        ...


    def copy4x4(self, src: "Matrix4x3dc", dest: list[float], off: int) -> None:
        ...


    def copy4x4(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
        ...


    def copy4x4(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
        ...


    def copy3x3(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
        ...


    def copy3x3(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
        ...


    def identity(self, dest: "Matrix4f") -> None:
        ...


    def identity(self, dest: "Matrix4x3f") -> None:
        ...


    def identity(self, dest: "Matrix3f") -> None:
        ...


    def identity(self, dest: "Matrix3x2f") -> None:
        ...


    def identity(self, dest: "Matrix3x2d") -> None:
        ...


    def identity(self, dest: "Matrix2f") -> None:
        ...


    def swap(self, m1: "Matrix4f", m2: "Matrix4f") -> None:
        ...


    def swap(self, m1: "Matrix4x3f", m2: "Matrix4x3f") -> None:
        ...


    def swap(self, m1: "Matrix3f", m2: "Matrix3f") -> None:
        ...


    def swap(self, m1: "Matrix2f", m2: "Matrix2f") -> None:
        ...


    def swap(self, m1: "Matrix2d", m2: "Matrix2d") -> None:
        ...


    def zero(self, dest: "Matrix4f") -> None:
        ...


    def zero(self, dest: "Matrix4x3f") -> None:
        ...


    def zero(self, dest: "Matrix3f") -> None:
        ...


    def zero(self, dest: "Matrix3x2f") -> None:
        ...


    def zero(self, dest: "Matrix3x2d") -> None:
        ...


    def zero(self, dest: "Matrix2f") -> None:
        ...


    def zero(self, dest: "Matrix2d") -> None:
        ...


    class MemUtilNIO(MemUtil):

        def put0(self, m: "Matrix4f", dest: "FloatBuffer") -> None:
            ...


        def putN(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put0(self, m: "Matrix4f", dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3_0(self, m: "Matrix4f", dest: "FloatBuffer") -> None:
            ...


        def put4x3_N(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x3(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x3_0(self, m: "Matrix4f", dest: "ByteBuffer") -> None:
            ...


        def put4x3(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix4f", dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix4f", dest: "FloatBuffer") -> None:
            ...


        def put3x4_N(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix4x3f", dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix4x3f", dest: "FloatBuffer") -> None:
            ...


        def put3x4_N(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put0(self, m: "Matrix4x3f", dest: "FloatBuffer") -> None:
            ...


        def putN(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put0(self, m: "Matrix4x3f", dest: "ByteBuffer") -> None:
            ...


        def putN(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put0(self, m: "Matrix3f", dest: "FloatBuffer") -> None:
            ...


        def putN(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put0(self, m: "Matrix3f", dest: "ByteBuffer") -> None:
            ...


        def putN(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix3f", dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4_0(self, m: "Matrix3f", dest: "FloatBuffer") -> None:
            ...


        def put3x4_N(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4L", offset: int, dest: "LongBuffer") -> None:
            ...


        def put(self, src: "Vector4L", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector4i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector3i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3L", offset: int, dest: "LongBuffer") -> None:
            ...


        def put(self, src: "Vector3L", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector2i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2i", offset: int, dest: "LongBuffer") -> None:
            ...


        def put(self, src: "Vector2L", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2L", offset: int, dest: "LongBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", offset: int, src: "ByteBuffer") -> None:
            ...


        def getTransposed(self, m: "Matrix4f", offset: int, src: "FloatBuffer") -> None:
            ...


        def getTransposed(self, m: "Matrix4f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix4d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix4x3d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix3d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix2d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector4f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4L", offset: int, src: "LongBuffer") -> None:
            ...


        def get(self, dst: "Vector4L", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector4i", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector3i", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3L", offset: int, src: "LongBuffer") -> None:
            ...


        def get(self, dst: "Vector3L", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector2L", offset: int, src: "LongBuffer") -> None:
            ...


        def get(self, dst: "Vector2i", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2L", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix4f", column: int, row: int, value: float) -> "Matrix4f":
            ...


        def get(self, m: "Matrix4d", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix4d", column: int, row: int, value: float) -> "Matrix4d":
            ...


        def get(self, m: "Matrix3f", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix3f", column: int, row: int, value: float) -> "Matrix3f":
            ...


        def get(self, m: "Matrix3d", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix3d", column: int, row: int, value: float) -> "Matrix3d":
            ...


        def getColumn(self, m: "Matrix4f", column: int, dest: "Vector4f") -> "Vector4f":
            ...


        def setColumn(self, v: "Vector4f", column: int, dest: "Matrix4f") -> "Matrix4f":
            ...


        def setColumn(self, v: "Vector4fc", column: int, dest: "Matrix4f") -> "Matrix4f":
            ...


        def copy(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
            ...


        def copy(self, src: "Matrix3fc", dest: "Matrix4f") -> None:
            ...


        def copy(self, src: "Matrix4fc", dest: "Matrix3f") -> None:
            ...


        def copy(self, src: "Matrix3fc", dest: "Matrix4x3f") -> None:
            ...


        def copy(self, src: "Matrix3x2fc", dest: "Matrix3x2f") -> None:
            ...


        def copy(self, src: "Matrix3x2dc", dest: "Matrix3x2d") -> None:
            ...


        def copy(self, src: "Matrix2fc", dest: "Matrix2f") -> None:
            ...


        def copy(self, src: "Matrix2dc", dest: "Matrix2d") -> None:
            ...


        def copy(self, src: "Matrix2fc", dest: "Matrix3f") -> None:
            ...


        def copy(self, src: "Matrix3fc", dest: "Matrix2f") -> None:
            ...


        def copy(self, src: "Matrix2fc", dest: "Matrix3x2f") -> None:
            ...


        def copy(self, src: "Matrix3x2fc", dest: "Matrix2f") -> None:
            ...


        def copy(self, src: "Matrix2dc", dest: "Matrix3d") -> None:
            ...


        def copy(self, src: "Matrix3dc", dest: "Matrix2d") -> None:
            ...


        def copy(self, src: "Matrix2dc", dest: "Matrix3x2d") -> None:
            ...


        def copy(self, src: "Matrix3x2dc", dest: "Matrix2d") -> None:
            ...


        def copy3x3(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
            ...


        def copy3x3(self, src: "Matrix4x3fc", dest: "Matrix4x3f") -> None:
            ...


        def copy3x3(self, src: "Matrix3fc", dest: "Matrix4x3f") -> None:
            ...


        def copy3x3(self, src: "Matrix3fc", dest: "Matrix4f") -> None:
            ...


        def copy4x3(self, src: "Matrix4x3fc", dest: "Matrix4f") -> None:
            ...


        def copy4x3(self, src: "Matrix4fc", dest: "Matrix4f") -> None:
            ...


        def copy(self, src: "Matrix4fc", dest: "Matrix4x3f") -> None:
            ...


        def copy(self, src: "Matrix4x3fc", dest: "Matrix4f") -> None:
            ...


        def copy(self, src: "Matrix4x3fc", dest: "Matrix4x3f") -> None:
            ...


        def copy(self, src: "Matrix3fc", dest: "Matrix3f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix4f") -> None:
            ...


        def copyTransposed(self, arr: list[float], off: int, dest: "Matrix4f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix3f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix4x3f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix3x2f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix3x2d") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix3x2d") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix2f") -> None:
            ...


        def copy(self, arr: list[float], off: int, dest: "Matrix2d") -> None:
            ...


        def copy(self, src: "Matrix4fc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix3fc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix4x3fc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix2fc", dest: list[float], off: int) -> None:
            ...


        def copy(self, src: "Matrix2dc", dest: list[float], off: int) -> None:
            ...


        def copy4x4(self, src: "Matrix4x3fc", dest: list[float], off: int) -> None:
            ...


        def copy4x4(self, src: "Matrix4x3dc", dest: list[float], off: int) -> None:
            ...


        def copy4x4(self, src: "Matrix4x3dc", dest: list[float], off: int) -> None:
            ...


        def copy3x3(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
            ...


        def copy3x3(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
            ...


        def copy4x4(self, src: "Matrix3x2fc", dest: list[float], off: int) -> None:
            ...


        def copy4x4(self, src: "Matrix3x2dc", dest: list[float], off: int) -> None:
            ...


        def identity(self, dest: "Matrix4f") -> None:
            ...


        def identity(self, dest: "Matrix4x3f") -> None:
            ...


        def identity(self, dest: "Matrix3f") -> None:
            ...


        def identity(self, dest: "Matrix3x2f") -> None:
            ...


        def identity(self, dest: "Matrix3x2d") -> None:
            ...


        def identity(self, dest: "Matrix2f") -> None:
            ...


        def swap(self, m1: "Matrix4f", m2: "Matrix4f") -> None:
            ...


        def swap(self, m1: "Matrix4x3f", m2: "Matrix4x3f") -> None:
            ...


        def swap(self, m1: "Matrix3f", m2: "Matrix3f") -> None:
            ...


        def swap(self, m1: "Matrix2f", m2: "Matrix2f") -> None:
            ...


        def swap(self, m1: "Matrix2d", m2: "Matrix2d") -> None:
            ...


        def zero(self, dest: "Matrix4f") -> None:
            ...


        def zero(self, dest: "Matrix4x3f") -> None:
            ...


        def zero(self, dest: "Matrix3f") -> None:
            ...


        def zero(self, dest: "Matrix3x2f") -> None:
            ...


        def zero(self, dest: "Matrix3x2d") -> None:
            ...


        def zero(self, dest: "Matrix2f") -> None:
            ...


        def zero(self, dest: "Matrix2d") -> None:
            ...


        def putMatrix3f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix3f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
            ...


        def putMatrix4f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix4f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
            ...


        def putMatrix4x3f(self, q: "Quaternionf", position: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix4x3f(self, q: "Quaternionf", position: int, dest: "FloatBuffer") -> None:
            ...


    class MemUtilUnsafe(MemUtilNIO):

        UNSAFE = None
        ADDRESS = None
        Matrix2f_m00 = None
        Matrix3f_m00 = None
        Matrix3d_m00 = None
        Matrix4f_m00 = None
        Matrix4d_m00 = None
        Matrix4x3f_m00 = None
        Matrix3x2f_m00 = None
        Vector4f_x = None
        Vector4i_x = None
        Vector3f_x = None
        Vector3i_x = None
        Vector2f_x = None
        Vector2i_x = None
        floatArrayOffset = None


        @staticmethod
        def getUnsafeInstance() -> "sun.misc.Unsafe":
            ...


        @staticmethod
        def put(m: "Matrix4f", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x3(m: "Matrix4f", destAddr: int) -> None:
            ...


        @staticmethod
        def put3x4(m: "Matrix4f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix4x3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x4(m: "Matrix4x3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put3x4(m: "Matrix4x3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x4(m: "Matrix4x3d", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x4(m: "Matrix3x2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x4(m: "Matrix3x2d", destAddr: int) -> None:
            ...


        @staticmethod
        def put3x3(m: "Matrix3x2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put3x3(m: "Matrix3x2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix4f", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x3Transposed(m: "Matrix4f", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix4x3f", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix3f", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix3x2f", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix4d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix4x3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix4d", destAddr: int) -> None:
            ...


        @staticmethod
        def putfTransposed(m: "Matrix4d", destAddr: int) -> None:
            ...


        @staticmethod
        def put4x3Transposed(m: "Matrix4d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix4x3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix3x2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putTransposed(m: "Matrix2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putfTransposed(m: "Matrix4x3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putfTransposed(m: "Matrix3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putfTransposed(m: "Matrix3x2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putfTransposed(m: "Matrix2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(m: "Matrix4d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(m: "Matrix4x3d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put3x4(m: "Matrix3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix3d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix3x2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix3x2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(m: "Matrix3d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(m: "Matrix2d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(m: "Matrix2d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector4d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(src: "Vector4d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector4f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector4i", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector4L", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector3f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector3d", destAddr: int) -> None:
            ...


        @staticmethod
        def putf(src: "Vector3d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector3i", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector3L", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector2f", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector2d", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector2i", destAddr: int) -> None:
            ...


        @staticmethod
        def put(src: "Vector2L", destAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix4f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix4f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix3f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix4x3f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix3x2f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix2f", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix4x3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix3x2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getTransposed(m: "Matrix4d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix4x3f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix4d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix4x3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getf(m: "Matrix4d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getf(m: "Matrix4x3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix3f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix3x2f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix3x2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getf(m: "Matrix3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix2f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(m: "Matrix2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def getf(m: "Matrix2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector4d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector4f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector4i", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector4L", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector3f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector3d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector3i", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector3L", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector2f", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector2d", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector2i", srcAddr: int) -> None:
            ...


        @staticmethod
        def get(dst: "Vector2L", srcAddr: int) -> None:
            ...


        @staticmethod
        def putMatrix3f(q: "Quaternionf", addr: int) -> None:
            ...


        @staticmethod
        def putMatrix4f(q: "Quaternionf", addr: int) -> None:
            ...


        @staticmethod
        def putMatrix4x3f(q: "Quaternionf", addr: int) -> None:
            ...


        def putMatrix3f(self, q: "Quaternionf", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix3f(self, q: "Quaternionf", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putMatrix4f(self, q: "Quaternionf", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix4f(self, q: "Quaternionf", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putMatrix4x3f(self, q: "Quaternionf", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putMatrix4x3f(self, q: "Quaternionf", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x3(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x4(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put3x3(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put4x3Transposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def putTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix4x3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putfTransposed(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put3x4(self, m: "Matrix3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix3x2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, m: "Matrix2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, m: "Matrix2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, m: "Matrix2d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def putf(self, m: "Matrix2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, src: "Vector4d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector4f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector4i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector4i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector3f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def putf(self, src: "Vector3d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector3i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector3i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2f", offset: int, dest: "FloatBuffer") -> None:
            ...


        def put(self, src: "Vector2f", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2d", offset: int, dest: "DoubleBuffer") -> None:
            ...


        def put(self, src: "Vector2d", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2i", offset: int, dest: "IntBuffer") -> None:
            ...


        def put(self, src: "Vector2i", offset: int, dest: "ByteBuffer") -> None:
            ...


        def put(self, src: "Vector2L", offset: int, dest: "LongBuffer") -> None:
            ...


        def put(self, src: "Vector2L", offset: int, dest: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4f", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix4f", column: int, row: int, value: float) -> "Matrix4f":
            ...


        def get(self, m: "Matrix4d", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix4d", column: int, row: int, value: float) -> "Matrix4d":
            ...


        def get(self, m: "Matrix3f", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix3f", column: int, row: int, value: float) -> "Matrix3f":
            ...


        def get(self, m: "Matrix3d", column: int, row: int) -> float:
            ...


        def set(self, m: "Matrix3d", column: int, row: int, value: float) -> "Matrix3d":
            ...


        def get(self, m: "Matrix4x3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix4d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix4x3d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix4x3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix3x2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix3d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, m: "Matrix2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, m: "Matrix2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def getf(self, m: "Matrix2d", offset: int, src: "FloatBuffer") -> None:
            ...


        def getf(self, m: "Matrix2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector4d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector4f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector4i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector4i", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector3f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector3d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector3i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector3i", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2f", offset: int, src: "FloatBuffer") -> None:
            ...


        def get(self, dst: "Vector2f", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2d", offset: int, src: "DoubleBuffer") -> None:
            ...


        def get(self, dst: "Vector2d", offset: int, src: "ByteBuffer") -> None:
            ...


        def get(self, dst: "Vector2i", offset: int, src: "IntBuffer") -> None:
            ...


        def get(self, dst: "Vector2i", offset: int, src: "ByteBuffer") -> None:
            ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from com.google.errorprone.annotations.concurrent import LazyInit
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util import Iterator
from java.util.function import Function
from java.util.function import ToIntFunction
from java.util.stream import Collector
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedMultiset(ImmutableMultiset, SortedMultiset):
    """
    A SortedMultiset whose contents will never change, with many other important properties
    detailed at ImmutableCollection.
    
    **Warning:** as with any sorted collection, you are strongly advised not to use a Comparator or Comparable type whose comparison behavior is *inconsistent with
    equals*. That is, `a.compareTo(b)` or `comparator.compare(a, b)` should equal zero
    *if and only if* `a.equals(b)`. If this advice is not followed, the resulting
    collection will not correctly obey its specification.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 12.0
    """

    @staticmethod
    def toImmutableSortedMultiset(comparator: "Comparator"["E"]) -> "Collector"["E", Any, "ImmutableSortedMultiset"["E"]]:
        """
        Returns a `Collector` that accumulates the input elements into a new `ImmutableMultiset`. Elements are sorted by the specified comparator.
        
        **Warning:** `comparator` should be *consistent with `equals`* as
        explained in the Comparator documentation.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def toImmutableSortedMultiset(comparator: "Comparator"["E"], elementFunction: "Function"["T", "E"], countFunction: "ToIntFunction"["T"]) -> "Collector"["T", Any, "ImmutableSortedMultiset"["E"]]:
        """
        Returns a `Collector` that accumulates elements into an `ImmutableSortedMultiset`
        whose elements are the result of applying `elementFunction` to the inputs, with counts
        equal to the result of applying `countFunction` to the inputs.
        
        If the mapped elements contain duplicates (according to `comparator`), the first
        occurrence in encounter order appears in the resulting multiset, with count equal to the sum of
        the outputs of `countFunction.applyAsInt(t)` for each `t` mapped to that element.

        Since
        - 22.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableSortedMultiset"["E"]:
        """
        Returns the empty immutable sorted multiset.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing a single element.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any element is null
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.

        Raises
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering. To create a copy of a `SortedMultiset` that preserves the comparator, call
        .copyOfSorted instead. This method iterates over `elements` at most once.
        
        Note that if `s` is a `Multiset<String>`, then `ImmutableSortedMultiset.copyOf(s)` returns an `ImmutableSortedMultiset<String>`
        containing each of the strings in `s`, while `ImmutableSortedMultiset.of(s)`
        returns an `ImmutableSortedMultiset<Multiset<String>>` containing one element (the given
        multiset itself).
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is not type-safe, as it may be called on elements that are not mutually
        comparable.

        Raises
        - ClassCastException: if the elements are not mutually comparable
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: Iterator["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by their natural
        ordering.
        
        This method is not type-safe, as it may be called on elements that are not mutually
        comparable.

        Raises
        - ClassCastException: if the elements are not mutually comparable
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(comparator: "Comparator"["E"], elements: Iterator["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by the given `Comparator`.

        Raises
        - NullPointerException: if `comparator` or any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(comparator: "Comparator"["E"], elements: Iterable["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the given elements sorted by the given `Comparator`. This method iterates over `elements` at most once.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if `comparator` or any of `elements` is null
        """
        ...


    @staticmethod
    def copyOfSorted(sortedMultiset: "SortedMultiset"["E"]) -> "ImmutableSortedMultiset"["E"]:
        """
        Returns an immutable sorted multiset containing the elements of a sorted multiset, sorted by
        the same `Comparator`. That behavior differs from .copyOf(Iterable), which always
        uses the natural ordering of the elements.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is safe to use even when `sortedMultiset` is a synchronized or concurrent
        collection that is currently being modified by another thread.

        Raises
        - NullPointerException: if `sortedMultiset` or any of its elements is null
        """
        ...


    def comparator(self) -> "Comparator"["E"]:
        ...


    def elementSet(self) -> "ImmutableSortedSet"["E"]:
        ...


    def descendingMultiset(self) -> "ImmutableSortedMultiset"["E"]:
        ...


    def pollFirstEntry(self) -> "Entry"["E"]:
        """
        
        
        This implementation is guaranteed to throw an UnsupportedOperationException.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def pollLastEntry(self) -> "Entry"["E"]:
        """
        
        
        This implementation is guaranteed to throw an UnsupportedOperationException.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def headMultiset(self, upperBound: "E", boundType: "BoundType") -> "ImmutableSortedMultiset"["E"]:
        ...


    def subMultiset(self, lowerBound: "E", lowerBoundType: "BoundType", upperBound: "E", upperBoundType: "BoundType") -> "ImmutableSortedMultiset"["E"]:
        ...


    def tailMultiset(self, lowerBound: "E", boundType: "BoundType") -> "ImmutableSortedMultiset"["E"]:
        ...


    @staticmethod
    def orderedBy(comparator: "Comparator"["E"]) -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted multisets with an explicit comparator. If the
        comparator has a more general type than the set being generated, such as creating a `SortedMultiset<Integer>` with a `Comparator<Number>`, use the Builder constructor
        instead.

        Raises
        - NullPointerException: if `comparator` is null
        """
        ...


    @staticmethod
    def reverseOrder() -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted multisets whose elements are ordered by the
        reverse of their natural ordering.
        
        Note: the type parameter `E` extends `Comparable<?>` rather than `Comparable<? super E>` as a workaround for javac <a
        href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6468354">bug 6468354</a>.
        """
        ...


    @staticmethod
    def naturalOrder() -> "Builder"["E"]:
        """
        Returns a builder that creates immutable sorted multisets whose elements are ordered by their
        natural ordering. The sorted multisets use Ordering.natural() as the comparator. This
        method provides more type-safety than .builder, as it can be called only for classes
        that implement Comparable.
        
        Note: the type parameter `E` extends `Comparable<?>` rather than `Comparable<? super E>` as a workaround for javac <a
        href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6468354">bug 6468354</a>.
        """
        ...


    @staticmethod
    def toImmutableMultiset() -> "Collector"["E", Any, "ImmutableMultiset"["E"]]:
        """
        Not supported. Use .toImmutableSortedMultiset instead. This method exists only to hide
        ImmutableMultiset.toImmutableMultiset from consumers of `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 21.0

        Deprecated
        - Use ImmutableSortedMultiset.toImmutableSortedMultiset.
        """
        ...


    @staticmethod
    def toImmutableMultiset(elementFunction: "Function"["T", "E"], countFunction: "ToIntFunction"["T"]) -> "Collector"["T", Any, "ImmutableMultiset"["E"]]:
        """
        Not supported. Use .toImmutableSortedMultiset instead. This method exists only to hide
        ImmutableMultiset.toImmutableMultiset from consumers of `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Since
        - 22.0

        Deprecated
        - Use ImmutableSortedMultiset.toImmutableSortedMultiset.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedMultiset.Builder"["E"]:
        """
        Not supported. Use .naturalOrder, which offers better type-safety, instead. This method
        exists only to hide ImmutableMultiset.builder from consumers of `ImmutableSortedMultiset`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMultiset.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a parameter of type `Comparable` to use ImmutableSortedMultiset.of(Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable).**
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable). **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable, Comparable) .
            **
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *remaining: Tuple["E", ...]) -> "ImmutableSortedMultiset"["E"]:
        """
        Not supported. **You are attempting to create a multiset that may contain a non-`Comparable` element.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass the parameters of type `Comparable` to use ImmutableSortedMultiset.of(Comparable, Comparable, Comparable, Comparable, Comparable,
            Comparable, Comparable...) . **
        """
        ...


    @staticmethod
    def copyOf(elements: list["Z"]) -> "ImmutableSortedMultiset"["Z"]:
        """
        Not supported. **You are attempting to create a multiset that may contain non-`Comparable` elements.** Proper calls will resolve to the version in `ImmutableSortedMultiset`, not this dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass parameters of type `Comparable` to use ImmutableSortedMultiset.copyOf(Comparable[]).**
        """
        ...


    class Builder(Builder):
        """
        A builder for creating immutable multiset instances, especially `public static final`
        multisets ("constant multisets"). Example:
        
        ````public static final ImmutableSortedMultiset<Bean> BEANS =
            new ImmutableSortedMultiset.Builder<Bean>(colorComparator())
                .addCopies(Bean.COCOA, 4)
                .addCopies(Bean.GARDEN, 6)
                .addCopies(Bean.RED, 8)
                .addCopies(Bean.BLACK_EYED, 10)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple multisets in series.

        Since
        - 12.0
        """

        def __init__(self, comparator: "Comparator"["E"]):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableSortedMultiset.orderedBy(Comparator).
            """
            ...


        def add(self, element: "E") -> "Builder"["E"]:
            """
            Adds `element` to the `ImmutableSortedMultiset`.

            Arguments
            - element: the element to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            """
            ...


        def add(self, *elements: Tuple["E", ...]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedMultiset`.

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addCopies(self, element: "E", occurrences: int) -> "Builder"["E"]:
            """
            Adds a number of occurrences of an element to this `ImmutableSortedMultiset`.

            Arguments
            - element: the element to add
            - occurrences: the number of occurrences of the element to add. May be zero, in which
                case no change will be made.

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            - IllegalArgumentException: if `occurrences` is negative, or if this operation
                would result in more than Integer.MAX_VALUE occurrences of the element
            """
            ...


        def setCount(self, element: "E", count: int) -> "Builder"["E"]:
            """
            Adds or removes the necessary occurrences of an element such that the element attains the
            desired count.

            Arguments
            - element: the element to add or remove occurrences of
            - count: the desired count of the element in this multiset

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `element` is null
            - IllegalArgumentException: if `count` is negative
            """
            ...


        def addAll(self, elements: Iterable["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedMultiset`.

            Arguments
            - elements: the `Iterable` to add to the `ImmutableSortedMultiset`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addAll(self, elements: Iterator["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSortedMultiset`.

            Arguments
            - elements: the elements to add to the `ImmutableSortedMultiset`

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def build(self) -> "ImmutableSortedMultiset"["E"]:
            """
            Returns a newly-created `ImmutableSortedMultiset` based on the contents of the `Builder`.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.inventory.PrepareInventoryResultEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import HandlerList
from org.bukkit.event.inventory import *
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PrepareInventoryResultEvent(InventoryEvent):
    """
    Called when an item is put in a slot and the result is calculated.
    """

    def __init__(self, inventory: "InventoryView", result: "ItemStack"):
        ...


    def getResult(self) -> "ItemStack":
        """
        Get result item, may be null.

        Returns
        - result item
        """
        ...


    def setResult(self, result: "ItemStack") -> None:
        """
        Set result item, may be null.

        Arguments
        - result: result item
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.TimeZone

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import Serializable
from java.time import ZoneId
from java.util import *
from jdk.internal.util import StaticProperty
from sun.security.action import GetPropertyAction
from sun.util.calendar import ZoneInfo
from sun.util.calendar import ZoneInfoFile
from sun.util.locale.provider import TimeZoneNameUtility
from typing import Any, Callable, Iterable, Tuple


class TimeZone(Serializable, Cloneable):
    """
    `TimeZone` represents a time zone offset, and also figures out daylight
    savings.
    
    
    Typically, you get a `TimeZone` using `getDefault`
    which creates a `TimeZone` based on the time zone where the program
    is running. For example, for a program running in Japan, `getDefault`
    creates a `TimeZone` object based on Japanese Standard Time.
    
    
    You can also get a `TimeZone` using `getTimeZone`
    along with a time zone ID. For instance, the time zone ID for the
    U.S. Pacific Time zone is "America/Los_Angeles". So, you can get a
    U.S. Pacific Time `TimeZone` object with:
    <blockquote>```
    TimeZone tz = TimeZone.getTimeZone("America/Los_Angeles");
    ```</blockquote>
    You can use the `getAvailableIDs` method to iterate through
    all the supported time zone IDs. You can then choose a
    supported ID to get a `TimeZone`.
    If the time zone you want is not represented by one of the
    supported IDs, then a custom time zone ID can be specified to
    produce a TimeZone. The syntax of a custom time zone ID is:
    
    <blockquote>```
    <a id="CustomID">*CustomID:*</a>
            `GMT` *Sign* *Hours* `:` *Minutes*
            `GMT` *Sign* *Hours* *Minutes*
            `GMT` *Sign* *Hours*
    *Sign:* one of
            `+ -`
    *Hours:*
            *Digit*
            *Digit* *Digit*
    *Minutes:*
            *Digit* *Digit*
    *Digit:* one of
            `0 1 2 3 4 5 6 7 8 9`
    ```</blockquote>
    
    *Hours* must be between 0 to 23 and *Minutes* must be
    between 00 to 59.  For example, "GMT+10" and "GMT+0010" mean ten
    hours and ten minutes ahead of GMT, respectively.
    
    The format is locale independent and digits must be taken from the
    Basic Latin block of the Unicode standard. No daylight saving time
    transition schedule can be specified with a custom time zone ID. If
    the specified string doesn't match the syntax, `"GMT"`
    is used.
    
    When creating a `TimeZone`, the specified custom time
    zone ID is normalized in the following syntax:
    <blockquote>```
    <a id="NormalizedCustomID">*NormalizedCustomID:*</a>
            `GMT` *Sign* *TwoDigitHours* `:` *Minutes*
    *Sign:* one of
            `+ -`
    *TwoDigitHours:*
            *Digit* *Digit*
    *Minutes:*
            *Digit* *Digit*
    *Digit:* one of
            `0 1 2 3 4 5 6 7 8 9`
    ```</blockquote>
    For example, TimeZone.getTimeZone("GMT-8").getID() returns "GMT-08:00".
    
    <h2>Three-letter time zone IDs</h2>
    
    For compatibility with JDK 1.1.x, some other three-letter time zone IDs
    (such as "PST", "CTT", "AST") are also supported. However, <strong>their
    use is deprecated</strong> because the same abbreviation is often used
    for multiple time zones (for example, "CST" could be U.S. "Central Standard
    Time" and "China Standard Time"), and the Java platform can then only
    recognize one of them.

    Author(s)
    - Mark Davis, David Goldsmith, Chen-Lieh Huang, Alan Liu

    See
    - SimpleTimeZone

    Since
    - 1.1
    """

    SHORT = 0
    """
    A style specifier for `getDisplayName()` indicating
    a short name, such as "PST."

    See
    - .LONG

    Since
    - 1.2
    """
    LONG = 1
    """
    A style specifier for `getDisplayName()` indicating
    a long name, such as "Pacific Standard Time."

    See
    - .SHORT

    Since
    - 1.2
    """


    def __init__(self):
        """
        Sole constructor.  (For invocation by subclass constructors, typically
        implicit.)
        """
        ...


    def getOffset(self, era: int, year: int, month: int, day: int, dayOfWeek: int, milliseconds: int) -> int:
        """
        Gets the time zone offset, for current date, modified in case of
        daylight savings. This is the offset to add to UTC to get local time.
        
        This method returns a historically correct offset if an
        underlying `TimeZone` implementation subclass
        supports historical Daylight Saving Time schedule and GMT
        offset changes.

        Arguments
        - era: the era of the given date.
        - year: the year in the given date.
        - month: the month in the given date.
        Month is 0-based. e.g., 0 for January.
        - day: the day-in-month of the given date.
        - dayOfWeek: the day-of-week of the given date.
        - milliseconds: the milliseconds in day in *standard*
        local time.

        Returns
        - the offset in milliseconds to add to GMT to get local time.

        See
        - Calendar.DST_OFFSET
        """
        ...


    def getOffset(self, date: int) -> int:
        """
        Returns the offset of this time zone from UTC at the specified
        date. If Daylight Saving Time is in effect at the specified
        date, the offset value is adjusted with the amount of daylight
        saving.
        
        This method returns a historically correct offset value if an
        underlying TimeZone implementation subclass supports historical
        Daylight Saving Time schedule and GMT offset changes.

        Arguments
        - date: the date represented in milliseconds since January 1, 1970 00:00:00 GMT

        Returns
        - the amount of time in milliseconds to add to UTC to get local time.

        See
        - Calendar.DST_OFFSET

        Since
        - 1.4
        """
        ...


    def setRawOffset(self, offsetMillis: int) -> None:
        """
        Sets the base time zone offset to GMT.
        This is the offset to add to UTC to get local time.
        
        If an underlying `TimeZone` implementation subclass
        supports historical GMT offset changes, the specified GMT
        offset is set as the latest GMT offset and the difference from
        the known latest GMT offset value is used to adjust all
        historical GMT offset values.

        Arguments
        - offsetMillis: the given base time zone offset to GMT.
        """
        ...


    def getRawOffset(self) -> int:
        """
        Returns the amount of time in milliseconds to add to UTC to get
        standard time in this time zone. Because this value is not
        affected by daylight saving time, it is called <I>raw
        offset</I>.
        
        If an underlying `TimeZone` implementation subclass
        supports historical GMT offset changes, the method returns the
        raw offset value of the current date. In Honolulu, for example,
        its raw offset changed from GMT-10:30 to GMT-10:00 in 1947, and
        this method always returns -36000000 milliseconds (i.e., -10
        hours).

        Returns
        - the amount of raw offset time in milliseconds to add to UTC.

        See
        - Calendar.ZONE_OFFSET
        """
        ...


    def getID(self) -> str:
        """
        Gets the ID of this time zone.

        Returns
        - the ID of this time zone.
        """
        ...


    def setID(self, ID: str) -> None:
        """
        Sets the time zone ID. This does not change any other data in
        the time zone object.

        Arguments
        - ID: the new time zone ID.
        """
        ...


    def getDisplayName(self) -> str:
        """
        Returns a long standard time name of this `TimeZone` suitable for
        presentation to the user in the default locale.
        
        This method is equivalent to:
        <blockquote>```
        getDisplayName(False, .LONG,
                       Locale.getDefault(Locale.Category.DISPLAY))
        ```</blockquote>

        Returns
        - the human-readable name of this time zone in the default locale.

        See
        - Locale.Category

        Since
        - 1.2
        """
        ...


    def getDisplayName(self, locale: "Locale") -> str:
        """
        Returns a long standard time name of this `TimeZone` suitable for
        presentation to the user in the specified `locale`.
        
        This method is equivalent to:
        <blockquote>```
        getDisplayName(False, .LONG, locale)
        ```</blockquote>

        Arguments
        - locale: the locale in which to supply the display name.

        Returns
        - the human-readable name of this time zone in the given locale.

        Raises
        - NullPointerException: if `locale` is `null`.

        See
        - .getDisplayName(boolean, int, Locale)

        Since
        - 1.2
        """
        ...


    def getDisplayName(self, daylight: bool, style: int) -> str:
        """
        Returns a name in the specified `style` of this `TimeZone`
        suitable for presentation to the user in the default locale. If the
        specified `daylight` is `True`, a Daylight Saving Time name
        is returned (even if this `TimeZone` doesn't observe Daylight Saving
        Time). Otherwise, a Standard Time name is returned.
        
        This method is equivalent to:
        <blockquote>```
        getDisplayName(daylight, style,
                       Locale.getDefault(Locale.Category.DISPLAY))
        ```</blockquote>

        Arguments
        - daylight: `True` specifying a Daylight Saving Time name, or
                        `False` specifying a Standard Time name
        - style: either .LONG or .SHORT

        Returns
        - the human-readable name of this time zone in the default locale.

        Raises
        - IllegalArgumentException: if `style` is invalid.

        See
        - java.text.DateFormatSymbols.getZoneStrings()

        Since
        - 1.2
        """
        ...


    def getDisplayName(self, daylight: bool, style: int, locale: "Locale") -> str:
        """
        Returns a name in the specified `style` of this `TimeZone`
        suitable for presentation to the user in the specified `locale`. If the specified `daylight` is `True`, a Daylight
        Saving Time name is returned (even if this `TimeZone` doesn't
        observe Daylight Saving Time). Otherwise, a Standard Time name is
        returned.
        
        When looking up a time zone name, the ResourceBundle.Control.getCandidateLocales(String,Locale) default
        {@code Locale search path of `ResourceBundle`} derived
        from the specified `locale` is used. (No ResourceBundle.Control.getFallbackLocale(String,Locale) fallback
        {@code Locale} search is performed.) If a time zone name in any
        `Locale` of the search path, including Locale.ROOT, is
        found, the name is returned. Otherwise, a string in the
        <a href="#NormalizedCustomID">normalized custom ID format</a> is returned.

        Arguments
        - daylight: `True` specifying a Daylight Saving Time name, or
                        `False` specifying a Standard Time name
        - style: either .LONG or .SHORT
        - locale: the locale in which to supply the display name.

        Returns
        - the human-readable name of this time zone in the given locale.

        Raises
        - IllegalArgumentException: if `style` is invalid.
        - NullPointerException: if `locale` is `null`.

        See
        - java.text.DateFormatSymbols.getZoneStrings()

        Since
        - 1.2
        """
        ...


    def getDSTSavings(self) -> int:
        """
        Returns the amount of time to be added to local standard time
        to get local wall clock time.
        
        The default implementation returns 3600000 milliseconds
        (i.e., one hour) if a call to .useDaylightTime()
        returns `True`. Otherwise, 0 (zero) is returned.
        
        If an underlying `TimeZone` implementation subclass
        supports historical and future Daylight Saving Time schedule
        changes, this method returns the amount of saving time of the
        last known Daylight Saving Time rule that can be a future
        prediction.
        
        If the amount of saving time at any given time stamp is
        required, construct a Calendar with this `TimeZone` and the time stamp, and call Calendar.get(int)
        Calendar.get`(`Calendar.DST_OFFSET`)`.

        Returns
        - the amount of saving time in milliseconds

        See
        - Calendar.ZONE_OFFSET

        Since
        - 1.4
        """
        ...


    def useDaylightTime(self) -> bool:
        """
        Queries if this `TimeZone` uses Daylight Saving Time.
        
        If an underlying `TimeZone` implementation subclass
        supports historical and future Daylight Saving Time schedule
        changes, this method refers to the last known Daylight Saving Time
        rule that can be a future prediction and may not be the same as
        the current rule. Consider calling .observesDaylightTime()
        if the current rule should also be taken into account.

        Returns
        - `True` if this `TimeZone` uses Daylight Saving Time,
                `False`, otherwise.

        See
        - Calendar.DST_OFFSET
        """
        ...


    def observesDaylightTime(self) -> bool:
        """
        Returns `True` if this `TimeZone` is currently in
        Daylight Saving Time, or if a transition from Standard Time to
        Daylight Saving Time occurs at any future time.
        
        The default implementation returns `True` if
        `useDaylightTime()` or `inDaylightTime(new Date())`
        returns `True`.

        Returns
        - `True` if this `TimeZone` is currently in
        Daylight Saving Time, or if a transition from Standard Time to
        Daylight Saving Time occurs at any future time; `False`
        otherwise.

        See
        - Calendar.DST_OFFSET

        Since
        - 1.7
        """
        ...


    def inDaylightTime(self, date: "Date") -> bool:
        """
        Queries if the given `date` is in Daylight Saving Time in
        this time zone.

        Arguments
        - date: the given Date.

        Returns
        - `True` if the given date is in Daylight Saving Time,
                `False`, otherwise.
        """
        ...


    @staticmethod
    def getTimeZone(ID: str) -> "TimeZone":
        """
        Gets the `TimeZone` for the given ID.

        Arguments
        - ID: the ID for a `TimeZone`, either an abbreviation
        such as "PST", a full name such as "America/Los_Angeles", or a custom
        ID such as "GMT-8:00". Note that the support of abbreviations is
        for JDK 1.1.x compatibility only and full names should be used.

        Returns
        - the specified `TimeZone`, or the GMT zone if the given ID
        cannot be understood.
        """
        ...


    @staticmethod
    def getTimeZone(zoneId: "ZoneId") -> "TimeZone":
        """
        Gets the `TimeZone` for the given `zoneId`.

        Arguments
        - zoneId: a ZoneId from which the time zone ID is obtained

        Returns
        - the specified `TimeZone`, or the GMT zone if the given ID
                cannot be understood.

        Raises
        - NullPointerException: if `zoneId` is `null`

        Since
        - 1.8
        """
        ...


    def toZoneId(self) -> "ZoneId":
        """
        Converts this `TimeZone` object to a `ZoneId`.

        Returns
        - a `ZoneId` representing the same time zone as this
                `TimeZone`

        Since
        - 1.8
        """
        ...


    @staticmethod
    def getAvailableIDs(rawOffset: int) -> list[str]:
        """
        Gets the available IDs according to the given time zone offset in milliseconds.

        Arguments
        - rawOffset: the given time zone GMT offset in milliseconds.

        Returns
        - an array of IDs, where the time zone for that ID has
        the specified GMT offset. For example, "America/Phoenix" and "America/Denver"
        both have GMT-07:00, but differ in daylight saving behavior.

        See
        - .getRawOffset()
        """
        ...


    @staticmethod
    def getAvailableIDs() -> list[str]:
        """
        Gets all the available IDs supported.

        Returns
        - an array of IDs.
        """
        ...


    @staticmethod
    def getDefault() -> "TimeZone":
        """
        Gets the default `TimeZone` of the Java virtual machine. If the
        cached default `TimeZone` is available, its clone is returned.
        Otherwise, the method takes the following steps to determine the default
        time zone.
        
        
        - Use the `user.timezone` property value as the default
        time zone ID if it's available.
        - Detect the platform time zone ID. The source of the
        platform time zone and ID mapping may vary with implementation.
        - Use `GMT` as the last resort if the given or detected
        time zone ID is unknown.
        
        
        The default `TimeZone` created from the ID is cached,
        and its clone is returned. The `user.timezone` property
        value is set to the ID upon return.

        Returns
        - the default `TimeZone`

        See
        - .setDefault(TimeZone)
        """
        ...


    @staticmethod
    def setDefault(zone: "TimeZone") -> None:
        """
        Sets the `TimeZone` that is returned by the `getDefault`
        method. `zone` is cached. If `zone` is null, the cached
        default `TimeZone` is cleared. This method doesn't change the value
        of the `user.timezone` property.

        Arguments
        - zone: the new default `TimeZone`, or null

        Raises
        - SecurityException: if the security manager's `checkPermission`
                                  denies `PropertyPermission("user.timezone",
                                  "write")`

        See
        - PropertyPermission
        """
        ...


    def hasSameRules(self, other: "TimeZone") -> bool:
        """
        Returns True if this zone has the same rule and offset as another zone.
        That is, if this zone differs only in ID, if at all.  Returns False
        if the other zone is null.

        Arguments
        - other: the `TimeZone` object to be compared with

        Returns
        - True if the other zone is not null and is the same as this one,
        with the possible exception of the ID

        Since
        - 1.2
        """
        ...


    def clone(self) -> "Object":
        """
        Creates a copy of this `TimeZone`.

        Returns
        - a clone of this `TimeZone`
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.Funnels

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Preconditions
from com.google.common.hash import *
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import OutputStream
from java.io import Serializable
from java.nio.charset import Charset
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Funnels:
    """
    Funnels for common types. All implementations are serializable.

    Author(s)
    - Dimitris Andreou

    Since
    - 11.0
    """

    @staticmethod
    def byteArrayFunnel() -> "Funnel"[list[int]]:
        """
        Returns a funnel that extracts the bytes from a `byte` array.
        """
        ...


    @staticmethod
    def unencodedCharsFunnel() -> "Funnel"["CharSequence"]:
        """
        Returns a funnel that extracts the characters from a `CharSequence`, a character at a
        time, without performing any encoding. If you need to use a specific encoding, use Funnels.stringFunnel(Charset) instead.

        Since
        - 15.0 (since 11.0 as `Funnels.stringFunnel()`.
        """
        ...


    @staticmethod
    def stringFunnel(charset: "Charset") -> "Funnel"["CharSequence"]:
        """
        Returns a funnel that encodes the characters of a `CharSequence` with the specified
        `Charset`.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def integerFunnel() -> "Funnel"["Integer"]:
        """
        Returns a funnel for integers.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def sequentialFunnel(elementFunnel: "Funnel"["E"]) -> "Funnel"[Iterable["E"]]:
        """
        Returns a funnel that processes an `Iterable` by funneling its elements in iteration
        order with the specified funnel. No separators are added between the elements.

        Since
        - 15.0
        """
        ...


    @staticmethod
    def longFunnel() -> "Funnel"["Long"]:
        """
        Returns a funnel for longs.

        Since
        - 13.0
        """
        ...


    @staticmethod
    def asOutputStream(sink: "PrimitiveSink") -> "OutputStream":
        """
        Wraps a `PrimitiveSink` as an OutputStream, so it is easy to Funnel.funnel
        funnel an object to a `PrimitiveSink` if there is already a way to write the contents of
        the object to an `OutputStream`.
        
        The `close` and `flush` methods of the returned `OutputStream` do nothing,
        and no method throws `IOException`.

        Since
        - 13.0
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.AbstractTransformFuture

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Function
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import ForOverride
from com.google.errorprone.annotations.concurrent import LazyInit
from java.util.concurrent import CancellationException
from java.util.concurrent import ExecutionException
from java.util.concurrent import Executor
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractTransformFuture(TrustedFuture, Runnable):
    """
    Implementations of `Futures.transform*`.
    """

    def run(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.conversations.ValidatingPrompt

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import ChatColor
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class ValidatingPrompt(Prompt):
    """
    ValidatingPrompt is the base class for any prompt that requires validation.
    ValidatingPrompt will keep replaying the prompt text until the user enters
    a valid response.
    """

    def __init__(self):
        ...


    def acceptInput(self, context: "ConversationContext", input: str) -> "Prompt":
        """
        Accepts and processes input from the user and validates it. If
        validation fails, this prompt is returned for re-execution, otherwise
        the next Prompt in the prompt graph is returned.

        Arguments
        - context: Context information about the conversation.
        - input: The input text from the user.

        Returns
        - This prompt or the next Prompt in the prompt graph.
        """
        ...


    def blocksForInput(self, context: "ConversationContext") -> bool:
        """
        Ensures that the prompt waits for the user to provide input.

        Arguments
        - context: Context information about the conversation.

        Returns
        - True.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.MethodProperty

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Method
from java.lang.reflect import Type
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.introspector import *
from org.yaml.snakeyaml.util import ArrayUtils
from typing import Any, Callable, Iterable, Tuple


class MethodProperty(GenericProperty):
    """
    
    A `MethodProperty` is a `Property` which is accessed through accessor
    methods (setX, getX). It is possible to have a `MethodProperty` which has only setter,
    only getter, or both. It is not possible to have a `MethodProperty` which has neither
    setter nor getter.
    """

    def __init__(self, property: "PropertyDescriptor"):
        ...


    def set(self, object: "Object", value: "Object") -> None:
        ...


    def get(self, object: "Object") -> "Object":
        ...


    def getAnnotations(self) -> list["Annotation"]:
        """
        Returns the annotations that are present on read and write methods of this property or empty
        `List` if there're no annotations.

        Returns
        - the annotations that are present on this property or empty `List` if there're no
                annotations
        """
        ...


    def getAnnotation(self, annotationType: type["A"]) -> "A":
        """
        Returns property's annotation for the given type or `null` if it's not present. If the
        annotation is present on both read and write methods, the annotation on read method takes
        precedence.

        Arguments
        - annotationType: the type of the annotation to be returned

        Returns
        - property's annotation for the given type or `null` if it's not present
        """
        ...


    def isWritable(self) -> bool:
        ...


    def isReadable(self) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.entity.Frog

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.entity import *
from org.bukkit.registry import RegistryAware
from org.bukkit.util import OldEnum
from typing import Any, Callable, Iterable, Tuple


class Frog(Animals):
    """
    A Frog.
    """

    def getTongueTarget(self) -> "Entity":
        """
        Gets the tongue target of this frog.

        Returns
        - tongue target or null if not set
        """
        ...


    def setTongueTarget(self, target: "Entity") -> None:
        """
        Sets the tongue target of this frog.

        Arguments
        - target: tongue target or null to clear
        """
        ...


    def getVariant(self) -> "Variant":
        """
        Get the variant of this frog.

        Returns
        - frog variant
        """
        ...


    def setVariant(self, variant: "Variant") -> None:
        """
        Set the variant of this frog.

        Arguments
        - variant: frog variant
        """
        ...
